@@ -37,10 +37,12 @@ async def _read_stdout(stdout):
             if not response:
                 print('stdout: (none response)')
                 await asyncio.sleep(1)
-            elif response.startswith(b"eyJNZXNzYWdlIjoiT"):  # This is the b64 start of a Slapp message.
+            elif response.startswith(b"eyJNZXNzYWdlIjo"):  # This is the b64 start of a Slapp message.
                 decoded_bytes = base64.b64decode(response)
                 response = json.loads(str(decoded_bytes, "utf-8"))
                 await response_function(response.get("Message", "Response does not contain Message."), response)
+            elif "Caching task done." in response:
+                await response_function("Caching task done.", {})
             else:
                 print('stdout: ' + response.decode('utf-8'))
         except Exception as e:
